<html>
<header>
<title> Modifica clienti PHP-Residence </title>
</header>
<body bgcolor=#ffffff>

<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "modifica_cliente.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
include("./dati/lingua.php");
$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
$tableregole = $PHPR_TAB_PRE."regole".$anno;
$tableanni = $PHPR_TAB_PRE."anni";
$tableclienti = $PHPR_TAB_PRE."clienti";
$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
$tableutenti = $PHPR_TAB_PRE."utenti";


$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
if ($id_utente) {

if ($id_utente != 1) {
$tableprivilegi = $PHPR_TAB_PRE."privilegi";
$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
else {
$anno_utente_attivato = "SI";
$privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
$priv_ins_clienti = risul_query($privilegi_globali_utente,0,priv_ins_clienti);
if (substr($priv_ins_clienti,1,1) == "s") $modifica_clienti = "SI";
if (substr($priv_ins_clienti,1,1) == "p") $modifica_clienti = "PROPRI";
if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p") $modifica_clienti = "NO";
if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p") $vedi_clienti = "NO";
$prefisso_clienti = risul_query($privilegi_globali_utente,0,prefisso_clienti);
$attiva_prefisso_clienti = substr($prefisso_clienti,0,1);
if ($attiva_prefisso_clienti != "n") {
$prefisso_clienti = explode(",",$prefisso_clienti);
$prefisso_clienti = $prefisso_clienti[1];
} # fine if ($prefisso_clienti != "n")
$contratti_consentiti = risul_query($privilegi_annuali_utente,0,contratti_consentiti);
$attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
if ($attiva_contratti_consentiti == "s") {
$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
unset($contratti_consentiti_vett);
for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
} # fine if ($attiva_contratti_consentiti == "s")
$priv_mod_prenota = risul_query($privilegi_annuali_utente,0,priv_mod_prenota);
$priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
$priv_mod_prenota_iniziate = substr($priv_mod_prenota,11,1);
$priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
} # fine else if (numlin_query($privilegi_annuali_utente) == 0)
} # fine if ($id_utente != 1)
else {
$anno_utente_attivato = "SI";
$modifica_clienti = "SI";
$vedi_clienti = "SI";
$attiva_prefisso_clienti = "n";
$attiva_contratti_consentiti = "n";
$priv_mod_prenotazioni = "s";
$priv_mod_prenota_iniziate = "s";
$priv_mod_prenota_ore = "000";
} # fine else if ($id_utente != 1)

$idclienti = addslashes($idclienti);

if ($modifica_clienti == "PROPRI" or $vedi_clienti == "PROPRI") {
$cliente_proprio = esegui_query("select idclienti from $tableclienti where idclienti = '$idclienti' and utente_inserimento = '$id_utente'");
if (numlin_query($cliente_proprio) == 0) $modifica_clienti = "NO";
} # fine if ($modifica_clienti == "PROPRI" or $vedi_clienti == "PROPRI")
if ($anno_utente_attivato == "SI" and $modifica_clienti != "NO" and $vedi_clienti != "NO" and $idclienti and controlla_num_pos($idclienti) == "SI") {


$stile_soldi = stile_soldi();
$stile_data = stile_data();

if ($modifica_cliente) {
if ($modifica_cliente != "Continua") {

if (!$d_cognome) { $d_cognome = "---"; }
if (!$d_nome) { $d_nome = "---"; }
if (!$d_datanascita) { $d_datanascita = "---"; }
else $d_datanascita_f = formatta_data($d_datanascita,$stile_data);
if (!$d_nazione) { $d_nazione = "---"; }
if (!$d_citta) { $d_citta= "---"; }
if (!$d_via) { $d_via = "---"; }
if (!$d_numcivico) { $d_numcivico = "---"; }
if (!$d_telefono) { $d_telefono = "---"; }
if (!$d_telefono2) { $d_telefono2 = "---"; }
if (!$d_telefono3) { $d_telefono3 = "---"; }
if (!$d_fax) { $d_fax = "---"; }
if (!$d_cap) { $d_cap = "---"; }
if (!$d_email) { $d_email = "---"; }
if (!$d_cognome2) { $d_cognome2 = "---"; }
if (!$d_nome2) { $d_nome2 = "---"; }
if (!$d_datanascita2) { $d_datanascita2_f = "---"; }
else $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);

$n_cognome = stripslashes($n_cognome);
$n_cognome = htmlspecialchars($n_cognome);
$n_cognome2 = stripslashes($n_cognome2);
$n_cognome2 = htmlspecialchars($n_cognome2);
$n_citta = stripslashes($n_citta);
$n_citta = htmlspecialchars($n_citta);
$n_nazione = stripslashes($n_nazione);
$n_nazione = htmlspecialchars($n_nazione);
$n_nomevia = stripslashes($n_nomevia);
$n_nomevia = htmlspecialchars($n_nomevia);
$n_nome = stripslashes($n_nome);
$n_nome = htmlspecialchars($n_nome);
$n_nome2 = stripslashes($n_nome2);
$n_nome2 = htmlspecialchars($n_nome2);
$n_commento = stripslashes($n_commento);
$n_commento = htmlspecialchars($n_commento);
$d_commento = stripslashes($d_commento);

$d_cognome = htmlspecialchars($d_cognome);
$d_cognome2 = htmlspecialchars($d_cognome2);
$d_citta = htmlspecialchars($d_citta);
$d_nazione = htmlspecialchars($d_nazione);
$d_nome = htmlspecialchars($d_nome);
$d_nome2 = htmlspecialchars($d_nome2);
$d_via = htmlspecialchars($d_via);
$d_commento = htmlspecialchars($d_commento);

if ($n_cognome) {
echo mex("Il cognome verr cambiato da",$pag)." <b>$d_cognome</b> ".mex("a",$pag)." <b>";
if ($attiva_prefisso_clienti == "p") echo $prefisso_clienti;
echo $n_cognome;
if ($attiva_prefisso_clienti == "s") echo $prefisso_clienti;
echo "</b>.<br>";
} # fine if ($n_cognome)
if ($n_nome) { echo mex("Il nome verr cambiato da",$pag)." <b>$d_nome</b> ".mex("a",$pag)." <b>$n_nome</b>.<br>"; }
if ($n_sesso) { echo mex("Il sesso verr cambiato a",$pag)." <b>$n_sesso</b>.<br>"; }
if ($n_mesenascita and $n_giornonascita and $n_annonascita) {
#$n_datanascita = date("M d, Y" , mktime(0,0,0,$n_mesenascita,$n_giornonascita,$n_annonascita));
$n_datanascita = $n_annonascita."-".$n_mesenascita."-".$n_giornonascita;
$n_datanascita_f = formatta_data($n_datanascita,$stile_data);
echo mex("La data di nascita  verr cambiata da",$pag)." <b>$d_datanascita_f</b> ".mex("a",$pag)." <b>$n_datanascita_f</b>.<br>";
} # fine if ($mesenascita and $giornonascita and $annonascita)

if ($id_nuovo_utente_inserimento != "" and $id_utente == 1) {
$id_nuovo_utente_inserimento = addslashes($id_nuovo_utente_inserimento);
$verifica_utente = esegui_query("select * from $tableutenti where idutenti = '$id_nuovo_utente_inserimento'");
if (numlin_query($verifica_utente) == 1) {
$nome_utente_nuovo = risul_query($verifica_utente,0,nome_utente);
echo mex("Si considerer l'utente",$pag)." <b>$nome_utente_nuovo</b> ".mex("come colui che ha inserito il cliente",$pag).".<br>";
} # fine if (numlin_query($verifica_utente) == 1)
else unset($id_nuovo_utente_inserimento);
} # fine if ($id_nuovo_utente_inserimento != "" and $id_utente == 1)

if ($n_telefono) { echo mex("Il telefono verr cambiato da",$pag)." <b>$d_telefono</b> ".mex("a",$pag)." <b>$n_telefono</b>.<br>"; }
if ($n_nomevia) {
include("./dati/lingua.php");
if ($lingua != "ita") include("./includes/lang/$lingua_mex/ordine_frasi.php");
if ($ordine_strada == 2) $n_nomevia = $n_nomevia . " " . $n_via;
else $n_nomevia = $n_via . " " . $n_nomevia;
echo mex("La via  verr cambiata da",$pag)." <b>$d_via</b> ".mex("a",$pag)." <b>$n_nomevia</b>.<br>";
} # fine if ($n_nomevia)
if ($n_numcivico) { echo mex("Il numero civico verr cambiato da",$pag)." <b>$d_numcivico</b> ".mex("a",$pag)." <b>$n_numcivico</b>.<br>"; }
if ($n_citta) { echo mex("La citt di residenza verr cambiata da",$pag)." <b>$d_citta</b> ".mex("a",$pag)." <b>$n_citta</b>.<br>"; }
if ($n_nazione) { echo mex("La nazione verr cambiata da",$pag)." <b>$d_nazione</b> ".mex("a",$pag)." <b>$n_nazione</b>.<br>"; }
if ($n_cap) { echo mex("Il CAP verr cambiato da",$pag)." <b>$d_cap</b> ".mex("a",$pag)." <b>$n_cap</b>.<br>"; }
if ($n_fax) { echo mex("Il fax verr cambiato da",$pag)." <b>$d_fax</b> ".mex("a",$pag)." <b>$n_fax</b>.<br>"; }
if ($n_email) { echo mex("L' email verr cambiata da",$pag)." <b>$d_email</b> ".mex("a",$pag)." <b>$n_email</b>.<br>"; }
if ($n_telefono2) { echo mex("Il 2 telefono verr cambiato da",$pag)." <b>$d_telefono2</b> ".mex("a",$pag)." <b>$n_telefono2</b>.<br>"; }
if ($n_telefono3) { echo mex("Il 3 telefono verr cambiato da",$pag)." <b>$d_telefono3</b> ".mex("a",$pag)." <b>$n_telefono3</b>.<br>"; }
if ($n_cognome2) { echo mex("Il cognome n2 verr cambiato da",$pag)." <b>$d_cognome2</b> ".mex("a",$pag)." <b>$n_cognome2</b>.<br>"; }
if ($n_nome2) { echo mex("Il nome n2 verr cambiato da",$pag)." <b>$d_nome2</b> ".mex("a",$pag)." <b>$n_nome2</b>.<br>"; }
if ($n_sesso2) { echo mex("Il sesso n2 verr cambiato a",$pag)." <b>$n_sesso2</b>.<br>"; }
if ($n_mesenascita2 and $n_giornonascita2 and $n_annonascita2) {
#$n_datanascita2 = date("M d, Y" , mktime(0,0,0,$n_mesenascita2,$n_giornonascita2,$n_annonascita2));
$n_datanascita2 = $n_annonascita2."-".$n_mesenascita2."-".$n_giornonascita2;
$n_datanascita2_f = formatta_data($n_datanascita2,$stile_data);
echo mex("La data di nascita n2 verr cambiata da",$pag)." <b>$d_datanascita2_f</b> ".mex("a",$pag)." <b>$n_datanascita2_f</b>.<br>";
} # fine if ($mesenascita2 and $giornonascita2 and $annonascita2)
if ($n_commento != $d_commento) { echo mex("Il <b>commento</b> verr cambiato",$pag).".<br>"; }

if ($c_nome) { echo mex("Il <b>nome</b> verr cancellato",$pag).".<br>"; }
if ($c_datanascita) { echo mex("La <b>data di nascita</b>  verr cancellata",$pag).".<br>"; }
if ($c_telefono) { echo mex("Il <b>telefono</b> verr cancellato",$pag).".<br>"; }
if ($c_via) { echo mex("La <b>via</b> verr cancellata",$pag).".<br>"; }
if ($c_numcivico) { echo mex("Il <b>n civico</b> verr cancellato",$pag).".<br>"; }
if ($c_citta) { echo mex("La <b>citt</b>  verr cancellata",$pag).".<br>"; }
if ($c_nazione) { echo mex("La <b>nazione</b> verr cancellata",$pag).".<br>"; }
if ($c_cap) { echo mex("Il <b>CAP</b> verr cancellato",$pag).".<br>"; }
if ($c_fax) { echo mex("Il <b>fax</b> verr cancellato",$pag).".<br>"; }
if ($c_email) { echo mex("L' <b>email</b>  verr cancellata",$pag).".<br>"; }
if ($c_telefono2) { echo mex("Il <b>2 telefono</b> verr cancellato",$pag).".<br>"; }
if ($c_telefono3) { echo mex("Il <b>3 telefono</b> verr cancellato",$pag).".<br>"; }
if ($c_cognome2) { echo mex("Il <b>cognome n 2</b> verr cancellato",$pag).".<br>"; }
if ($c_nome2) { echo mex("Il <b>nome n 2</b> verr cancellato",$pag).".<br>"; }
if ($c_datanascita2) { echo mex("La <b>data di nascita n 2</b>  verr cancellata",$pag).".<br>"; }
echo "<form method=\"post\" action=\"modifica_cliente.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">

<input type=\"hidden\" name=\"n_cognome\" value=\"$n_cognome\">
<input type=\"hidden\" name=\"n_nome\" value=\"$n_nome\">
<input type=\"hidden\" name=\"n_sesso\" value=\"$n_sesso\">
<input type=\"hidden\" name=\"n_datanascita\" value=\"$n_datanascita\">
<input type=\"hidden\" name=\"id_nuovo_utente_inserimento\" value=\"$id_nuovo_utente_inserimento\">
<input type=\"hidden\" name=\"n_telefono\" value=\"$n_telefono\">
<input type=\"hidden\" name=\"n_nomevia\" value=\"$n_nomevia\">
<input type=\"hidden\" name=\"n_numcivico\" value=\"$n_numcivico\">
<input type=\"hidden\" name=\"n_citta\" value=\"$n_citta\">
<input type=\"hidden\" name=\"n_nazione\" value=\"$n_nazione\">
<input type=\"hidden\" name=\"n_cap\" value=\"$n_cap\">
<input type=\"hidden\" name=\"n_fax\" value=\"$n_fax\">
<input type=\"hidden\" name=\"n_email\" value=\"$n_email\">
<input type=\"hidden\" name=\"n_telefono2\" value=\"$n_telefono2\">
<input type=\"hidden\" name=\"n_telefono3\" value=\"$n_telefono3\">
<input type=\"hidden\" name=\"n_cognome2\" value=\"$n_cognome2\">
<input type=\"hidden\" name=\"n_nome2\" value=\"$n_nome2\">
<input type=\"hidden\" name=\"n_sesso2\" value=\"$n_sesso2\">
<input type=\"hidden\" name=\"n_datanascita2\" value=\"$n_datanascita2\">
<input type=\"hidden\" name=\"n_commento\" value=\"$n_commento\">
<input type=\"hidden\" name=\"d_commento\" value=\"$d_commento\">

<input type=\"hidden\" name=\"c_nome\" value=\"$c_nome\">
<input type=\"hidden\" name=\"c_datanascita\" value=\"$c_datanascita\">
<input type=\"hidden\" name=\"c_telefono\" value=\"$c_telefono\">
<input type=\"hidden\" name=\"c_via\" value=\"$c_via\">
<input type=\"hidden\" name=\"c_numcivico\" value=\"$c_numcivico\">
<input type=\"hidden\" name=\"c_citta\" value=\"$c_citta\">
<input type=\"hidden\" name=\"c_nazione\" value=\"$c_nazione\">
<input type=\"hidden\" name=\"c_cap\" value=\"$c_cap\">
<input type=\"hidden\" name=\"c_fax\" value=\"$c_fax\">
<input type=\"hidden\" name=\"c_email\" value=\"$c_email\">
<input type=\"hidden\" name=\"c_telefono2\" value=\"$c_telefono2\">
<input type=\"hidden\" name=\"c_telefono3\" value=\"$c_telefono3\">
<input type=\"hidden\" name=\"c_cognome2\" value=\"$c_cognome2\">
<input type=\"hidden\" name=\"c_nome2\" value=\"$c_nome2\">
<input type=\"hidden\" name=\"c_datanascita2\" value=\"$c_datanascita2\">
<input type=\"hidden\" name=\"modifica_cliente\" value=\"Continua\">
<input type=\"submit\" name=\"modifica_cliente_vedi\" value=\"".mex("Continua",$pag)."\">
<hr width=\"95%\">
</form>";
} # fine if ($modifica_cliente != "Continua")

else {
$tabelle_lock = array("$tableclienti");
$altre_tab_lock = array("$tableutenti");
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
if ($n_cognome) {
if (get_magic_quotes_gpc()) $n_cognome = stripslashes($n_cognome);
$n_cognome = addslashes($n_cognome);
$n_cognome_maius = ucwords($n_cognome);
if ($attiva_prefisso_clienti == "p") $n_cognome_maius = $prefisso_clienti.$n_cognome_maius;
if ($attiva_prefisso_clienti == "s") $n_cognome_maius = $n_cognome_maius.$prefisso_clienti;
esegui_query("update $tableclienti set cognome = '$n_cognome_maius' where idclienti = '$idclienti' ");
} # fine if ($n_cognome)
if ($n_nome) {
if (get_magic_quotes_gpc()) $n_nome = stripslashes($n_nome);
$n_nome = addslashes($n_nome);
$n_nome_maius = ucwords($n_nome);
esegui_query("update $tableclienti set nome = '$n_nome_maius' where idclienti = '$idclienti' ");
} # fine if ($n_nome)
if ($n_sesso) {
$n_sesso = addslashes($n_sesso);
esegui_query("update $tableclienti set sesso = '$n_sesso' where idclienti = '$idclienti' ");
} # fine if ($n_sesso)
if ($n_datanascita) {
$n_datanascita = addslashes($n_datanascita);
esegui_query("update $tableclienti set datanascita = '$n_datanascita' where idclienti = '$idclienti' ");
} # fine if ($n_datanascita)

if ($id_nuovo_utente_inserimento != "" and $id_utente == 1) {
$id_nuovo_utente_inserimento = addslashes($id_nuovo_utente_inserimento);
$verifica_utente = esegui_query("select * from $tableutenti where idutenti = '$id_nuovo_utente_inserimento'");
if (numlin_query($verifica_utente) == 1) esegui_query("update $tableclienti set utente_inserimento = '$id_nuovo_utente_inserimento' where idclienti = '$idclienti' ");
} # fine if ($id_nuovo_utente_inserimento != "" and $id_utente == 1)

if ($n_telefono) {
if (get_magic_quotes_gpc()) $n_telefono = stripslashes($n_telefono);
$n_telefono = addslashes($n_telefono);
esegui_query("update $tableclienti set telefono = '$n_telefono' where idclienti = '$idclienti' ");
} # fine if ($n_telefono)
if ($n_nomevia) {
if (get_magic_quotes_gpc()) $n_nomevia = stripslashes($n_nomevia);
$n_nomevia = addslashes($n_nomevia);
$n_nomevia_maius = ucwords($n_nomevia);
esegui_query("update $tableclienti set via = '$n_nomevia_maius' where idclienti = '$idclienti' ");
} # fine if ($n_nomevia)
if ($n_numcivico) {
if (get_magic_quotes_gpc()) $n_numcivico = stripslashes($n_numcivico);
$n_numcivico = addslashes($n_numcivico);
esegui_query("update $tableclienti set numcivico = '$n_numcivico' where idclienti = '$idclienti' ");
} # fine if ($n_numcivico)
if ($n_citta) {
if (get_magic_quotes_gpc()) $n_citta = stripslashes($n_citta);
$n_citta = addslashes($n_citta);
$n_citta_maius = ucwords($n_citta);
esegui_query("update $tableclienti set citta = '$n_citta_maius' where idclienti = '$idclienti' ");
} # fine if ($n_citta)
if ($n_nazione) {
if (get_magic_quotes_gpc()) $n_nazione = stripslashes($n_nazione);
$n_nazione = addslashes($n_nazione);
$n_nazione_maius = ucwords($n_nazione);
esegui_query("update $tableclienti set nazione = '$n_nazione_maius' where idclienti = '$idclienti' ");
} # fine if ($n_nazione)
if ($n_cap) {
if (get_magic_quotes_gpc()) $n_cap = stripslashes($n_cap);
$n_cap = addslashes($n_cap);
esegui_query("update $tableclienti set cap = '$n_cap' where idclienti = '$idclienti' ");
} # fine if ($n_cap)
if ($n_fax) {
if (get_magic_quotes_gpc()) $n_fax = stripslashes($n_fax);
$n_fax = addslashes($n_fax);
esegui_query("update $tableclienti set fax = '$n_fax' where idclienti = '$idclienti' ");
} # fine if ($n_fax)
if ($n_email) {
if (get_magic_quotes_gpc()) $n_email = stripslashes($n_email);
$n_email = addslashes($n_email);
esegui_query("update $tableclienti set email = '$n_email' where idclienti = '$idclienti' ");
} # fine if ($n_email)
if ($n_telefono2) {
if (get_magic_quotes_gpc()) $n_telefono2 = stripslashes($n_telefono2);
$n_telefono2 = addslashes($n_telefono2);
esegui_query("update $tableclienti set telefono2 = '$n_telefono2' where idclienti = '$idclienti' ");
} # fine if ($n_telefono2)
if ($n_telefono3) {
if (get_magic_quotes_gpc()) $n_telefono3 = stripslashes($n_telefono3);
$n_telefono3 = addslashes($n_telefono3);
esegui_query("update $tableclienti set telefono3 = '$n_telefono3' where idclienti = '$idclienti' ");
} # fine if ($n_telefono3)
if ($n_cognome2) {
if (get_magic_quotes_gpc()) $n_cognome2 = stripslashes($n_cognome2);
$n_cognome2 = addslashes($n_cognome2);
$n_cognome2_maius = ucwords($n_cognome2);
esegui_query("update $tableclienti set cognome2 = '$n_cognome2_maius' where idclienti = '$idclienti' ");
} # fine if ($n_cognome2)
if ($n_nome2) {
if (get_magic_quotes_gpc()) $n_nome2 = stripslashes($n_nome2);
$n_nome2 = addslashes($n_nome2);
$n_nome2_maius = ucwords($n_nome2);
esegui_query("update $tableclienti set nome2 = '$n_nome2_maius' where idclienti = '$idclienti' ");
} # fine if ($n_nome2)
if ($n_sesso2) {
$n_sesso2 = addslashes($n_sesso2);
esegui_query("update $tableclienti set sesso2 = '$n_sesso2' where idclienti = '$idclienti' ");
} # fine if ($n_sesso2)
if ($n_datanascita2) {
$n_datanascita2 = addslashes($n_datanascita2);
esegui_query("update $tableclienti set datanascita2 = '$n_datanascita2' where idclienti = '$idclienti' ");
} # fine if ($n_datanascita2)
if ($n_commento != $d_commento) {
if (get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
$n_commento = addslashes($n_commento);
esegui_query("update $tableclienti set commento = '$n_commento' where idclienti = '$idclienti' ");
} # fine if ($n_commento != $d_commento)

if ($c_nome) {
esegui_query("update $tableclienti set nome = '' where idclienti = '$idclienti' ");
} # fine if ($c_nome)
if ($c_datanascita) {
esegui_query("update $tableclienti set datanascita = null where idclienti = '$idclienti' ");
} # fine if ($c_datanascita)
if ($c_telefono) {
esegui_query("update $tableclienti set telefono = '' where idclienti = '$idclienti' ");
} # fine if ($c_telefono)
if ($c_via) {
esegui_query("update $tableclienti set via = '' where idclienti = '$idclienti' ");
} # fine if ($c_via)
if ($c_numcivico) {
esegui_query("update $tableclienti set numcivico = '' where idclienti = '$idclienti' ");
} # fine if ($c_numcivico)
if ($c_citta) {
esegui_query("update $tableclienti set citta = '' where idclienti = '$idclienti' ");
} # fine if ($c_citta)
if ($c_nazione) {
esegui_query("update $tableclienti set nazione = '' where idclienti = '$idclienti' ");
} # fine if ($c_nazione)
if ($c_cap) {
esegui_query("update $tableclienti set cap = '' where idclienti = '$idclienti' ");
} # fine if ($c_cap)
if ($c_fax) {
esegui_query("update $tableclienti set fax = '' where idclienti = '$idclienti' ");
} # fine if ($c_fax)
if ($c_email) {
esegui_query("update $tableclienti set email = '' where idclienti = '$idclienti' ");
} # fine if ($c_email)
if ($c_telefono2) {
esegui_query("update $tableclienti set telefono2 = '' where idclienti = '$idclienti' ");
} # fine if ($c_telefono2)
if ($c_telefono3) {
esegui_query("update $tableclienti set telefono3 = '' where idclienti = '$idclienti' ");
} # fine if ($c_telefono3)
if ($c_cognome2) {
esegui_query("update $tableclienti set cognome2 = '' where idclienti = '$idclienti' ");
} # fine if ($c_cognome2)
if ($c_nome2) {
esegui_query("update $tableclienti set nome2 = '' where idclienti = '$idclienti' ");
} # fine if ($c_nome2)
if ($c_datanascita2) {
esegui_query("update $tableclienti set datanascita2 = null where idclienti = '$idclienti' ");
} # fine if ($c_datanascita2)
echo mex("Il cliente",$pag)." $idclienti ".mex(" stato modificato",$pag).".<br>";
unlock_tabelle($tabelle_lock);
} # fine else if ($modifica_cliente != "Continua")

echo "<center>
<form method=\"post\" action=\"modifica_cliente.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">";
echo "<input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
<br></form></center>";
} # fine if ($modifica_cliente)

else {



# Form per modificare il cliente.
echo "<center><font size=+2><b>".mex("Modifica i dati del cliente",$pag)." $idclienti</b></font><br></center><br>";

$cliente = esegui_query("select * from $tableclienti where idclienti = '$idclienti'");
$d_cognome = risul_query($cliente,0,cognome);
$d_nome = risul_query($cliente,0,nome);
$d_sesso = risul_query($cliente,0,sesso);
$d_telefono = risul_query($cliente,0,telefono);
$d_via = risul_query($cliente,0,via);
$d_numcivico = risul_query($cliente,0,numcivico);
$d_citta = risul_query($cliente,0,citta);
$d_nazione = risul_query($cliente,0,nazione);
$d_cap = risul_query($cliente,0,cap);
$d_fax = risul_query($cliente,0,fax);
$d_email = risul_query($cliente,0,email);
$d_datanascita = risul_query($cliente,0,datanascita);
if ($d_datanascita) $d_datanascita_f = formatta_data($d_datanascita,$stile_data);
$d_telefono2 = risul_query($cliente,0,telefono2);
$d_telefono3 = risul_query($cliente,0,telefono3);
$d_cognome2 = risul_query($cliente,0,cognome2);
$d_nome2 = risul_query($cliente,0,nome2);
$d_sesso2 = risul_query($cliente,0,sesso2);
$d_datanascita2 = risul_query($cliente,0,datanascita2);
if ($d_datanascita2) $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);
$d_commento = risul_query($cliente,0,commento);

$d_cognome = htmlspecialchars($d_cognome);
$d_cognome2 = htmlspecialchars($d_cognome2);
$d_citta = htmlspecialchars($d_citta);
$d_nazione = htmlspecialchars($d_nazione);
$d_nome = htmlspecialchars($d_nome);
$d_nome2 = htmlspecialchars($d_nome2);
$d_via = htmlspecialchars($d_via);
$d_commento = htmlspecialchars($d_commento);

echo "<form method=\"post\" action=\"modifica_cliente.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<table cellspacing=2 cellpadding=5>
<tr><td>".mex("Cognome",$pag).": <b>$d_cognome</b></td><td>".mex("cambia in",$pag)." ";
if ($attiva_prefisso_clienti == "p") echo $prefisso_clienti;
echo "<input type=\"text\" name=\"n_cognome\" size=\"20\">";
if ($attiva_prefisso_clienti == "s") echo $prefisso_clienti;
echo "</td></tr>
<tr><td>".mex("Nome",$pag).": <b>$d_nome</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_nome\" size=\"20\">
<br><input type=\"checkbox\" name=\"c_nome\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Sesso",$pag).": <b>$d_sesso</b></td>
<td>".mex("cambia in",$pag)." <select name=\"n_sesso\">
<option value=\"\" selected>-</option>
<option value=\"m\">m</option>
<option value=\"f\">f</option>
</select></td></tr>
<tr><td>".mex("Data di nascita",$pag).": <b>$d_datanascita_f</b></td>
<td>".mex("cambia in",$pag).": 
<select name=\"n_giornonascita\">
<option value=\"\" selected>--</option>";
for ( $num = 1; $num <= 31; $num = $num + 1) {
if (strlen($num) == 1) $num = "0".$num;
echo "<option value=\"$num\">$num</option>";
} # fine for $num
echo "</select>/
<select name=\"n_mesenascita\">
<option value=\"\" selected>--</option>";
for ( $num = 1; $num <= 12; $num = $num + 1) {
if (strlen($num) == 1) $num = "0".$num;
echo "<option value=\"$num\">$num</option>";
} # fine for $num
echo "</select>/
<input type=\"text\" name=\"n_annonascita\" size=\"5\" maxlength=\"4\" value=\"19\">
<br><input type=\"checkbox\" name=\"c_datanascita\" value=\"SI\">".mex("cancella",$pag)."</td></tr>";

if ($id_utente == 1) {
$tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
$num_tutti_utenti = numlin_query($tutti_utenti);
if ($num_tutti_utenti > 1) {
$id_utente_inserimento = risul_query($cliente,0,utente_inserimento);
unset($option_select_utenti);
for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
$idutenti = risul_query($tutti_utenti,$num1,idutenti);
if ($idutenti != $id_utente_inserimento) {
$nome_utente_option = risul_query($tutti_utenti,$num1,nome_utente);
$option_select_utenti .= "<option value=\"$idutenti\">$nome_utente_option</option>";
} # fine if ($idutenti != $id_utente_inserimento)
else $nome_utente_inserimento = risul_query($tutti_utenti,$num1,nome_utente);
} # fine for $num1
echo "<tr><td>
".mex("Inserito da",$pag)." <b>$nome_utente_inserimento</b>
</td><td>
 ".mex("cambia in",$pag)." <select name=\"id_nuovo_utente_inserimento\">
<option value=\"\" selected>----</option>
$option_select_utenti
</select></td></tr>";
} # fine if ($num_tutti_utenti > 1)
} # fine if ($id_utente == 1)

echo "<tr><td>".mex("Telefono",$pag).": <b>$d_telefono</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_telefono\">
<br><input type=\"checkbox\" name=\"c_telefono\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Via",$pag).": <b>$d_via</b></td>
<td>".mex("cambia in",$pag).": 
<select name=\"n_via\">
<option value=\"".mex("Via",$pag)."\" selected>".mex("Via",$pag)."</option>
<option value=\"".mex("Piazza",$pag)."\">".mex("Piazza",$pag)."</option>
<option value=\"".mex("Viale",$pag)."\">".mex("Viale",$pag)."</option>
<option value=\"".mex("Piazzale",$pag)."\">".mex("Piazzale",$pag)."</option>
<option value=\"".mex("Vicolo",$pag)."\">".mex("Vicolo",$pag)."</option>
<option value=\"\">-----</option>
</select>
<input type=\"text\" name=\"n_nomevia\">
<br><input type=\"checkbox\" name=\"c_via\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Numero civico",$pag).": <b>$d_numcivico</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_numcivico\" size=\"4\">
<br><input type=\"checkbox\" name=\"c_numcivico\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Citt",$pag).": <b>$d_citta</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_citta\">
<br><input type=\"checkbox\" name=\"c_citta\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Nazione",$pag).": <b>$d_nazione</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_nazione\">
<br><input type=\"checkbox\" name=\"c_nazione\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("CAP",$pag).": <b>$d_cap</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_cap\" size=\"6\">
<br><input type=\"checkbox\" name=\"c_cap\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Fax",$pag).": <b>$d_fax</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_fax\">
<br><input type=\"checkbox\" name=\"c_fax\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Email",$pag).": <b><a href=\"mailto:$d_email\">$d_email</a></b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_email\" size=\"30\">
<br><input type=\"checkbox\" name=\"c_email\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("2 telefono",$pag).": <b>$d_telefono2</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_telefono2\">
<br><input type=\"checkbox\" name=\"c_telefono2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("3 telefono",$pag).": <b>$d_telefono3</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_telefono3\">
<br><input type=\"checkbox\" name=\"c_telefono3\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Cognome n2",$pag).": <b>$d_cognome2</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_cognome2\">
<br><input type=\"checkbox\" name=\"c_cognome2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Nome n2",$pag).": <b>$d_nome2</b></td>
<td>".mex("cambia in",$pag).": 
<input type=\"text\" name=\"n_nome2\">
<br><input type=\"checkbox\" name=\"c_nome2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
<tr><td>".mex("Sesso n2",$pag).": <b>$d_sesso2</b></td>
<td>cambia in <select name=\"n_sesso2\">
<option value=\"\" selected>-</option>
<option value=\"m\">m</option>
<option value=\"f\">f</option>
</select></td></tr>
<tr><td>".mex("Data di nascita n2",$pag).": <b>$d_datanascita2_f</b></td>
<td>".mex("cambia in",$pag).": 
<select name=\"n_giornonascita2\">
<option value=\"\" selected>--</option>";
for ( $num = 1; $num <= 31; $num = $num + 1) {
if (strlen($num) == 1) $num = "0".$num;
echo "<option value=\"$num\">$num</option>";
} # fine for $num
echo "</select>/
<select name=\"n_mesenascita2\">
<option value=\"\" selected>--</option>";
for ( $num = 1; $num <= 12; $num = $num + 1) {
if (strlen($num) == 1) $num = "0".$num;
echo "<option value=\"$num\">$num</option>";
} # fine for $num
echo "</select>/
<input type=\"text\" name=\"n_annonascita2\" size=\"5\" maxlength=\"4\" value=\"19\">
<br><input type=\"checkbox\" name=\"c_datanascita2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
</table>
".mex("Commento",$pag).":<br>
<textarea name=\"n_commento\" rows=3 cols=45 wrap=\"virtual\">$d_commento</textarea><br>";


echo "<center>

<input type=\"hidden\" name=\"d_cognome\" value=\"$d_cognome\">
<input type=\"hidden\" name=\"d_nome\" value=\"$d_nome\">
<input type=\"hidden\" name=\"d_sesso\" value=\"$d_sesso\">
<input type=\"hidden\" name=\"d_datanascita\" value=\"$d_datanascita\">
<input type=\"hidden\" name=\"d_nazione\" value=\"$d_nazione\">
<input type=\"hidden\" name=\"d_citta\" value=\"$d_citta\">
<input type=\"hidden\" name=\"d_via\" value=\"$d_via\">
<input type=\"hidden\" name=\"d_numcivico\" value=\"$d_numcivico\">
<input type=\"hidden\" name=\"d_telefono\" value=\"$d_telefono\">
<input type=\"hidden\" name=\"d_telefono2\" value=\"$d_telefono2\">
<input type=\"hidden\" name=\"d_telefono3\" value=\"$d_telefono3\">
<input type=\"hidden\" name=\"d_fax\" value=\"$d_fax\">
<input type=\"hidden\" name=\"d_cap\" value=\"$d_cap\">
<input type=\"hidden\" name=\"d_email\" value=\"$d_email\">
<input type=\"hidden\" name=\"d_cognome2\" value=\"$d_cognome2\">
<input type=\"hidden\" name=\"d_nome2\" value=\"$d_nome2\">
<input type=\"hidden\" name=\"d_sesso2\" value=\"$d_sesso2\">
<input type=\"hidden\" name=\"d_datanascita2\" value=\"$d_datanascita2\">
<input type=\"hidden\" name=\"d_commento\" value=\"$d_commento\">

<input type=\"submit\" name=\"modifica_cliente\" value=\"".mex("Modifica i dati del cliente",$pag)."\">
</center></form>";

if ($tipo_tabella) { $origine = "visualizza_tabelle.php"; }
echo "<center><hr width=\"95%\">
<form method=\"post\" action=\"visualizza_contratto.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\"><input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">

<input type=\"hidden\" name=\"cognome\" value=\"$d_cognome\">
<input type=\"hidden\" name=\"nome\" value=\"$d_nome\">
<input type=\"hidden\" name=\"sesso\" value=\"$d_sesso\">
<input type=\"hidden\" name=\"datanascita\" value=\"$d_datanascita\">
<input type=\"hidden\" name=\"nazione\" value=\"$d_nazione\">
<input type=\"hidden\" name=\"citta\" value=\"$d_citta\">
<input type=\"hidden\" name=\"via\" value=\"$d_via\">
<input type=\"hidden\" name=\"numcivico\" value=\"$d_numcivico\">
<input type=\"hidden\" name=\"telefono\" value=\"$d_telefono\">
<input type=\"hidden\" name=\"telefono2\" value=\"$d_telefono2\">
<input type=\"hidden\" name=\"telefono3\" value=\"$d_telefono3\">
<input type=\"hidden\" name=\"fax\" value=\"$d_fax\">
<input type=\"hidden\" name=\"cap\" value=\"$d_cap\">
<input type=\"hidden\" name=\"email\" value=\"$d_email\">
<input type=\"hidden\" name=\"cognome2\" value=\"$d_cognome2\">
<input type=\"hidden\" name=\"nome2\" value=\"$d_nome2\">
<input type=\"hidden\" name=\"sesso2\" value=\"$d_sesso2\">
<input type=\"hidden\" name=\"datanascita2\" value=\"$d_datanascita2\">

<input type=\"submit\" name=\"torna\" value=\"".mex("Visualizza il contratto",$pag)."\">
".mex("di tipo",$pag)." 
<select name=\"tipo_contratto\">";
$nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
$nomi_contratti = risul_query($nomi_contratti,0,valpersonalizza);
$nomi_contratti = explode("#@&",$nomi_contratti);
$num_nomi_contratti = count($nomi_contratti);
for ($num1 = 0 ; $num1 < $num_nomi_contratti ; $num1++) {
$dati_nome_contratto = explode("#?&",$nomi_contratti[$num1]);
$nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
} # fine for $num1
for ($num_contratto = 1 ; $num_contratto <= 18 ; $num_contratto++) {
if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
if ($nome_contratto[$num_contratto]) $num_contratto_vedi = $nome_contratto[$num_contratto];
else $num_contratto_vedi = $num_contratto;
echo "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
} # fine if ($attiva_contratti_consentiti == "n" or...
} # fine for $num1
echo "</select><br></form><hr width=\"95%\">";



if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente ($anno);
$anni = esegui_query("select * from $tableanni order by idanni");
$num_anni = numlin_query($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_mostra = risul_query($anni,$num1,idanni);
$tableprenota_mostra = $PHPR_TAB_PRE."prenota".$anno_mostra;
$tableperiodi_mostra = $PHPR_TAB_PRE."periodi".$anno_mostra;
$prenotazioni = esegui_query("select * from $tableprenota_mostra where idclienti = '$idclienti'");
$num_prenotazioni = numlin_query($prenotazioni);
if ($num_prenotazioni != 0) {
echo "<br><font size=+1><b>".mex("Prenotazioni del cliente",$pag)." $d_cognome ".mex("nel",$pag)." $anno_mostra</b></font>
<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
<tr><td>N</td>
<td align=\"center\">".mex("Cognome_del_cliente",$pag)."</td>
<td align=\"center\">".mex("Data_iniziale",$pag)."</td>
<td align=\"center\">".mex("Data_finale",$pag)."</td>
<td align=\"center\"><font size=-1>".mex("Tariffa_completa",$pag)."</font></td>
<td align=\"center\">".mex("Caparra",$pag)."</td>
<td align=\"center\">".mex("Pagato",$pag)."</td>
<td align=\"center\"><font size=-2>".mex("App.",$pag)."</font></td>
<td align=\"center\"><font size=-2>".mex("Pers",$pag).".</font></td>
<td align=\"center\">".mex("Commento",$pag)."</td></tr>";

$data_inizio_assoluta = esegui_query("select datainizio from $tableperiodi_mostra where idperiodi = 1");
$data_inizio_assoluta = risul_query($data_inizio_assoluta,0,datainizio);
$costo_tot_TOT = 0;
$caparra_TOT = 0;
$pagato_TOT = 0;

for ($num2 = 0 ; $num2 < $num_prenotazioni ; $num2 = $num2 + 1) {
$numero = risul_query($prenotazioni,$num2,idprenota);
$appartamento = risul_query($prenotazioni,$num2,idappartamenti);
$commento = risul_query($prenotazioni,$num2,commento);
if (!$commento) { $commento = "&nbsp;"; }

$id_data_inizio = risul_query($prenotazioni,$num2,iddatainizio);
if ($id_data_inizio == 0) { $data_inizio = "<".$data_inizio_assoluta; }
else {
$data_inizio = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_inizio");
$data_inizio = risul_query($data_inizio,0,datainizio);
$data_inizio_f = formatta_data($data_inizio,$stile_data);
} # fine else if ($id_data_inizio == 0)
$id_data_fine = risul_query($prenotazioni,$num2,iddatafine);
$data_fine = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_fine");
$data_fine = risul_query($data_fine,0,datafine);
$data_fine_f = formatta_data($data_fine,$stile_data);
$mese = explode("-",$data_inizio);
$mese = $mese[1];

$num_persone = risul_query($prenotazioni,$num2,num_persone);
if (!$num_persone or $num_persone == 0) { $num_persone = "?"; }
$n_letti_agg = 0;
$costi_aggiuntivi_int = risul_query($prenotazioni,$num2,costiaggiuntivi);
if ($costi_aggiuntivi_int) {
$costi_aggiuntivi = explode("#@&",$costi_aggiuntivi_int);
$num_costi_aggiuntivi = count($costi_aggiuntivi);
} # fine if ($d_costi_aggiuntivi)
else { $num_costi_aggiuntivi = 0; }
for ($numca = 0 ; $numca < $num_costi_aggiuntivi ; $numca++) {
$d_costi_aggiuntivi = explode("#?&",$costi_aggiuntivi[$numca]);
if ($d_costi_aggiuntivi[0] == "cf" and $d_costi_aggiuntivi[4] == "s") {
$n_letti_agg = $n_letti_agg + $d_costi_aggiuntivi[3];
} # fine if ($d_costi_aggiuntivi[0] == "cf" and $d_costi_aggiuntivi[4] == "s")
if ($d_costi_aggiuntivi[0] == "cs" and $d_costi_aggiuntivi[5] == "s") {
$n_letti_agg = $n_letti_agg + $d_costi_aggiuntivi[3];
} # fine if ($d_costi_aggiuntivi[0] == "cs" and $d_costi_aggiuntivi[5] == "s")
if ($d_costi_aggiuntivi[0] == "cp" and $d_costi_aggiuntivi[5] == "s") {
$n_letti_agg = $n_letti_agg + $d_costi_aggiuntivi[2];
} # fine if ($d_costi_aggiuntivi[0] == "cp" and $d_costi_aggiuntivi[5] == "s")
} # fine for $numca

$caparra = risul_query($prenotazioni,$num2,caparra);
if (!$caparra) { $caparra = 0; }
$caparra_p = punti_in_num($caparra,$stile_soldi);
$pagato = risul_query($prenotazioni,$num2,pagato);
if (!$pagato) { $pagato = 0; }
$pagato_p = punti_in_num($pagato,$stile_soldi);
$costo_tot = risul_query($prenotazioni,$num2,tariffa_tot);
if (!$costo_tot) { $costo_tot = 0; }
$costo_tot_p = punti_in_num($costo_tot,$stile_soldi);
if ($pagato < $caparra) { $colore = "#CC0000"; }
else { if ($pagato < $costo_tot) { $colore = "#FFCC00"; } }

$link_modifica = "SI";
if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
if ($priv_mod_prenotazioni == "p") {
$utente_inserimento = risul_query($prenotazioni,$num2,utente_inserimento);
if ($utente_inserimento != $id_utente) $link_modifica = "NO";
} # fine if ($priv_mod_prenotazioni == "p")
if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_inizio) $link_modifica = "NO";
if ($priv_mod_prenota_ore != "000") {
$adesso = date("YmdHis");
$data_ins = risul_query($prenotazioni,$num2,datainserimento);
$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
if ($adesso > $limite) $link_modifica = "NO";
} # fine if ($priv_mod_prenota_ore != "000")

if ($anno == $anno_mostra and $link_modifica == "SI") {
echo "<tr><td align=\"center\"><a href=\"modifica_prenota.php?id_prenota=$numero&anno=$anno&id_sessione=$id_sessione&origine=visualizza_tabelle.php\">$numero</a></td>";
} # fine if ($anno = $anno_mostra)
else { echo "<tr><td align=\"center\">$numero</td>"; }
echo "<td align=\"center\">$d_cognome</td>
<td align=\"center\">$data_inizio_f</td>
<td align=\"center\">$data_fine_f</td>
<td align=\"center\">$costo_tot_p</td>
<td align=\"center\">$caparra_p</td>
<td align=\"center\"";
if ($colore) { echo " bgcolor =\"$colore\""; }
echo ">$pagato_p</td>
<td align=\"center\">$appartamento</td>
<td align=\"center\">$num_persone";
if ($n_letti_agg != 0) { echo "+$n_letti_agg"; }
echo "</td>
<td align=\"center\"><font size=-2>$commento</font></td></tr>";

$costo_tot_TOT = $costo_tot_TOT + $costo_tot;
$caparra_TOT = $caparra_TOT + $caparra;
$pagato_TOT = $pagato_TOT + $pagato;
} # fine for $num2

if ($num_prenotazioni > 1) {
$costo_tot_TOT_p = punti_in_num($costo_tot_TOT,$stile_soldi);
$caparra_TOT_p = punti_in_num($caparra_TOT,$stile_soldi);
$pagato_TOT_p = punti_in_num($pagato_TOT,$stile_soldi);
echo "<tr><td align=\"center\" colspan=\"4\"><b><i>".mex("TOTALE",$pag)."</i></b></td>
<td align=\"center\">$costo_tot_TOT_p</td>
<td align=\"center\">$caparra_TOT_p</td>
<td align=\"center\">$pagato_TOT_p</td>
<td align=\"center\">&nbsp;</td>
<td align=\"center\">&nbsp;</td>
<td align=\"center\">&nbsp;</td></tr>";
} # fine if ($num_prenotazioni > 1)

echo "</table><br>";
} # fine if ($num_prenotazioni != 0)
} # fine for $num1

echo "<hr width=\"95%\">
<form method=\"post\" action=\"$origine\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
</form></center>";


} # fine else if ($modifica_cliente)


} # fine if ($anno_utente_attivato == "SI" and...
} # fine if ($id_utente)



?>

</body>
</html>
